@@ -44,6 +44,9 @@
 namespace GNU_gama { namespace local {
 
 
+bool refine_obsdh_reductions(GNU_gama::local::LocalNetwork* IS);
+
+
 class TestLinearizationVisitor : public AllObservationsVisitor
 {
 private:
@@ -216,7 +219,7 @@ TestLinearization(GNU_gama::local::LocalNetwork* IS, OutStream& out,
   // from adjusted coordinates
   // ===============================================================
   {
-    const int M = IS->sum_observations();
+    const int M = IS->observations_count();
 
     Vec dif_m(M);   // difference in computation of adjusted observation
     Vec dif_p(M);   //               corresponds to positional shift
@@ -276,8 +279,8 @@ TestLinearization(GNU_gama::local::LocalNetwork* IS, OutStream& out,
 
           out << "\n"
                << T_GaMa_tstlin_Differences
-              << "\n"
-              << underline(T_GaMa_tstlin_Differences, '*')
+              // 2.16 << "\n"
+              // 2.16 << underline(T_GaMa_tstlin_Differences, '*')
               << "\n\n";
 
           out.width(IS->maxw_obs());
@@ -371,6 +374,8 @@ TestLinearization(GNU_gama::local::LocalNetwork* IS, OutStream& out,
 
             predcs = cs;  // previous standpoint ID
           }
+
+        out << "\n\n";
       }
   }
 
